@@ -31,7 +31,7 @@ import os
 from fnmatch import fnmatch
 import hashlib
 
-VERSION = "1.8.6"
+VERSION = "1.8.7"
 
 DEFAULT_CCN_THRESHOLD = 15
 
@@ -325,46 +325,46 @@ class CodeReader(object):
     def eof(self):
         pass
 
-    @staticmethod
-    def _generate_tokens(source_code, addition):
-        # DONOT put any sub groups in the regex. Good for performance
-        _until_end = r"(?:\\\n|[^\n])*"
-        combined_symbals = ["||", "&&", "===", "!==", "==", "!=", "<=", ">=",
-                            "<<", ">>>", "++", ">>", "--", '+=', '-=',
-                            '*=', '/=', '^=', '&=', '|=']
-        token_pattern = re.compile(
-            r"(?:\w+" +
-            r"|/\*.*?\*/" +
-            addition +
-            r"|\"(?:\\.|[^\"])*\"" +
-            r"|\'(?:\\.|[^\'])*?\'" +
-            r"|//" + _until_end +
-            r"|\#" +
-            r"|:=|::|\*\*" +
-            r"|" + r"|".join(re.escape(s) for s in combined_symbals) +
-            r"|\\\n" +
-            r"|\n" +
-            r"|[^\S\n]+" +
-            r"|.)", re.M | re.S)
-        macro = ""
-        for token in token_pattern.findall(source_code):
-            if macro:
-                if token == "\\\n" or "\n" not in token:
-                    macro += token
-                else:
-                    yield macro
-                    yield token
-                    macro = ""
-            elif token == "#":
-                macro = token
-            else:
-                yield token
-        if macro:
-            yield macro
-
     @staticmethod
     def generate_tokens(source_code, addition=''):
-        return [t for t in CodeReader._generate_tokens(source_code, addition)]
+        def _generate_tokens(source_code, addition):
+            # DONOT put any sub groups in the regex. Good for performance
+            _until_end = r"(?:\\\n|[^\n])*"
+            combined_symbals = ["||", "&&", "===", "!==", "==", "!=", "<=",
+                                ">=",
+                                "<<", ">>>", "++", ">>", "--", '+=', '-=',
+                                '*=', '/=', '^=', '&=', '|=']
+            token_pattern = re.compile(
+                r"(?:\w+" +
+                r"|/\*.*?\*/" +
+                addition +
+                r"|\"(?:\\.|[^\"])*\"" +
+                r"|\'(?:\\.|[^\'])*?\'" +
+                r"|//" + _until_end +
+                r"|\#" +
+                r"|:=|::|\*\*" +
+                r"|" + r"|".join(re.escape(s) for s in combined_symbals) +
+                r"|\\\n" +
+                r"|\n" +
+                r"|[^\S\n]+" +
+                r"|.)", re.M | re.S)
+            macro = ""
+            for token in token_pattern.findall(source_code):
+                if macro:
+                    if token == "\\\n" or "\n" not in token:
+                        macro += token
+                    else:
+                        yield macro
+                        yield token
+                        macro = ""
+                elif token == "#":
+                    macro = token
+                else:
+                    yield token
+            if macro:
+                yield macro
+
+        return [t for t in _generate_tokens(source_code, addition)]
 
 
 class CCppCommentsMixin(object):  # pylint: disable=R0903
@@ -387,6 +387,7 @@ except ImportError:
     pass
 
 
+# pylint: disable=R0903
 class CLikeReader(CodeReader, CCppCommentsMixin):
 
     ''' This is the reader for C, C++ and Java. '''
@@ -410,7 +411,7 @@ class CLikeReader(CodeReader, CCppCommentsMixin):
                         self.context.add_condition()
                     elif macro.group(1) == 'include':
                         yield "#include"
-                        yield macro.group(2)
+                        yield macro.group(2) or "\"\""
                     for _ in macro.group(2).splitlines()[1:]:
                         yield '\n'
                 else:
@@ -504,7 +505,7 @@ class CLikeReader(CodeReader, CCppCommentsMixin):
             self._state = self._state_imp
         elif token == ":":
             self._state = self._state_initialization_list
-        elif not token[0].isalpha() or token[0] == '_':
+        elif not (token[0].isalpha() or token[0] == '_'):
             self._state = self._state_global
         else:
             self._state = self._state_old_c_params
