@@ -174,6 +174,14 @@ class Test_c_cpp_lizard(unittest.TestCase):
         self.assertEqual(1, len(result))
         self.assertEqual("int( * fun ( ) )", result[0].name)
 
+    def test_underscore(self):
+        from lizard import CodeReader
+        generate_tokens = CodeReader.generate_tokens
+        result = get_cpp_function_list(''' a() _() { }''')
+        self.assertEqual(1, len(result))
+
+
+
 
 
 class Test_Preprocessing(unittest.TestCase):
